.bk-root {
  @charset "UTF-8";
  /* Functional styling;
 * These styles are required for noUiSlider to function.
 * You don't need to change these rules to apply your design.
 */
  /* Painting and performance;
 * Browsers can paint handles in their own layer.
 */
  /* Slider size and handle placement;
 */
  /* Styling;
 */
  /* Handles and cursors;
 */
  /* Handle stripes;
 */
  /* Disabled state;
 */
  /* Base;
 *
 */
  /* Values;
 *
 */
  /* Markings;
 *
 */
  /* Horizontal layout;
 *
 */
  /* Vertical layout;
 *
 */
  /*!
 * Pikaday
 * Copyright © 2014 David Bushell | BSD & MIT license | https://dbushell.com/
 */
  /*
clear child float (pika-lendar), using the famous micro clearfix hack
http://nicolasgallagher.com/micro-clearfix-hack/
*/
  /* styling for abbr */
}
.bk-root .bk-input {
  display: inline-block;
  width: 100%;
  flex-grow: 1;
  -webkit-flex-grow: 1;
  min-height: 31px;
  padding: 0 12px;
  background-color: #fff;
  border: 1px solid #ccc;
  border-radius: 4px;
}
.bk-root .bk-input:focus {
  border-color: #66afe9;
  outline: 0;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
}
.bk-root .bk-input::placeholder,
.bk-root .bk-input:-ms-input-placeholder,
.bk-root .bk-input::-moz-placeholder,
.bk-root .bk-input::-webkit-input-placeholder {
  color: #999;
  opacity: 1;
}
.bk-root .bk-input[disabled],
.bk-root .bk-input[readonly] {
  cursor: not-allowed;
  background-color: #eee;
  opacity: 1;
}
.bk-root select[multiple].bk-input,
.bk-root select[size].bk-input,
.bk-root textarea.bk-input {
  height: auto;
}
.bk-root .bk-input-group {
  width: 100%;
  height: 100%;
  display: inline-flex;
  display: -webkit-inline-flex;
  flex-wrap: nowrap;
  -webkit-flex-wrap: nowrap;
  align-items: start;
  -webkit-align-items: start;
  flex-direction: column;
  -webkit-flex-direction: column;
  white-space: nowrap;
}
.bk-root .bk-input-group.bk-inline {
  flex-direction: row;
  -webkit-flex-direction: row;
}
.bk-root .bk-input-group.bk-inline > *:not(:first-child) {
  margin-left: 5px;
}
.bk-root .bk-input-group input[type="checkbox"] + span,
.bk-root .bk-input-group input[type="radio"] + span {
  position: relative;
  top: -2px;
  margin-left: 3px;
}
.bk-root .bk-slider-title {
  white-space: nowrap;
}
.bk-root .bk-slider-value {
  font-weight: 600;
}
.bk-root .bk-noUi-target,
.bk-root .bk-noUi-target * {
  -webkit-touch-callout: none;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
  -webkit-user-select: none;
  -ms-touch-action: none;
  touch-action: none;
  -ms-user-select: none;
  -moz-user-select: none;
  user-select: none;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.bk-root .bk-noUi-target {
  position: relative;
  direction: ltr;
}
.bk-root .bk-noUi-base {
  width: 100%;
  height: 100%;
  position: relative;
  z-index: 1;
  /* Fix 401 */
}
.bk-root .bk-noUi-connect {
  position: absolute;
  right: 0;
  top: 0;
  left: 0;
  bottom: 0;
}
.bk-root .bk-noUi-origin {
  position: absolute;
  height: 0;
  width: 0;
}
.bk-root .bk-noUi-handle {
  position: relative;
  z-index: 1;
}
.bk-root .bk-noUi-state-tap .bk-noUi-connect,
.bk-root .bk-noUi-state-tap .bk-noUi-origin {
  -webkit-transition: top 0.3s, right 0.3s, bottom 0.3s, left 0.3s;
  transition: top 0.3s, right 0.3s, bottom 0.3s, left 0.3s;
}
.bk-root .bk-noUi-state-drag * {
  cursor: inherit !important;
}
.bk-root .bk-noUi-base,
.bk-root .bk-noUi-handle {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
}
.bk-root .bk-noUi-horizontal {
  height: 18px;
}
.bk-root .bk-noUi-horizontal .bk-noUi-handle {
  width: 34px;
  height: 28px;
  left: -17px;
  top: -6px;
}
.bk-root .bk-noUi-vertical {
  width: 18px;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle {
  width: 28px;
  height: 34px;
  left: -6px;
  top: -17px;
}
.bk-root .bk-noUi-target {
  background: #FAFAFA;
  border-radius: 4px;
  border: 1px solid #D3D3D3;
  box-shadow: inset 0 1px 1px #F0F0F0, 0 3px 6px -5px #BBB;
}
.bk-root .bk-noUi-connect {
  background: #3FB8AF;
  border-radius: 4px;
  box-shadow: inset 0 0 3px rgba(51, 51, 51, 0.45);
  -webkit-transition: background 450ms;
  transition: background 450ms;
}
.bk-root .bk-noUi-draggable {
  cursor: ew-resize;
}
.bk-root .bk-noUi-vertical .bk-noUi-draggable {
  cursor: ns-resize;
}
.bk-root .bk-noUi-handle {
  border: 1px solid #D9D9D9;
  border-radius: 3px;
  background: #FFF;
  cursor: default;
  box-shadow: inset 0 0 1px #FFF, inset 0 1px 7px #EBEBEB, 0 3px 6px -3px #BBB;
}
.bk-root .bk-noUi-active {
  box-shadow: inset 0 0 1px #FFF, inset 0 1px 7px #DDD, 0 3px 6px -3px #BBB;
}
.bk-root .bk-noUi-handle:before,
.bk-root .bk-noUi-handle:after {
  content: "";
  display: block;
  position: absolute;
  height: 14px;
  width: 1px;
  background: #E8E7E6;
  left: 14px;
  top: 6px;
}
.bk-root .bk-noUi-handle:after {
  left: 17px;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle:before,
.bk-root .bk-noUi-vertical .bk-noUi-handle:after {
  width: 14px;
  height: 1px;
  left: 6px;
  top: 14px;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle:after {
  top: 17px;
}
.bk-root [disabled] .bk-noUi-connect {
  background: #B8B8B8;
}
.bk-root [disabled].bk-noUi-target,
.bk-root [disabled].bk-noUi-handle,
.bk-root [disabled] .bk-noUi-handle {
  cursor: not-allowed;
}
.bk-root .bk-noUi-pips,
.bk-root .bk-noUi-pips * {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.bk-root .bk-noUi-pips {
  position: absolute;
  color: #999;
}
.bk-root .bk-noUi-value {
  position: absolute;
  white-space: nowrap;
  text-align: center;
}
.bk-root .bk-noUi-value-sub {
  color: #ccc;
  font-size: 10px;
}
.bk-root .bk-noUi-marker {
  position: absolute;
  background: #CCC;
}
.bk-root .bk-noUi-marker-sub {
  background: #AAA;
}
.bk-root .bk-noUi-marker-large {
  background: #AAA;
}
.bk-root .bk-noUi-pips-horizontal {
  padding: 10px 0;
  height: 80px;
  top: 100%;
  left: 0;
  width: 100%;
}
.bk-root .bk-noUi-value-horizontal {
  -webkit-transform: translate3d(-50%, 50%, 0);
  transform: translate3d(-50%, 50%, 0);
}
.bk-root .bk-noUi-marker-horizontal.bk-noUi-marker {
  margin-left: -1px;
  width: 2px;
  height: 5px;
}
.bk-root .bk-noUi-marker-horizontal.bk-noUi-marker-sub {
  height: 10px;
}
.bk-root .bk-noUi-marker-horizontal.bk-noUi-marker-large {
  height: 15px;
}
.bk-root .bk-noUi-pips-vertical {
  padding: 0 10px;
  height: 100%;
  top: 0;
  left: 100%;
}
.bk-root .bk-noUi-value-vertical {
  -webkit-transform: translate3d(0, 50%, 0);
  transform: translate3d(0, 50%, 0);
  padding-left: 25px;
}
.bk-root .bk-noUi-marker-vertical.bk-noUi-marker {
  width: 5px;
  height: 2px;
  margin-top: -1px;
}
.bk-root .bk-noUi-marker-vertical.bk-noUi-marker-sub {
  width: 10px;
}
.bk-root .bk-noUi-marker-vertical.bk-noUi-marker-large {
  width: 15px;
}
.bk-root .bk-noUi-tooltip {
  display: block;
  position: absolute;
  border: 1px solid #D9D9D9;
  border-radius: 3px;
  background: #fff;
  color: #000;
  padding: 5px;
  text-align: center;
  white-space: nowrap;
}
.bk-root .bk-noUi-horizontal .bk-noUi-tooltip {
  -webkit-transform: translate(-50%, 0);
  transform: translate(-50%, 0);
  left: 50%;
  bottom: 120%;
}
.bk-root .bk-noUi-vertical .bk-noUi-tooltip {
  -webkit-transform: translate(0, -50%);
  transform: translate(0, -50%);
  top: 50%;
  right: 120%;
}
.bk-root .bk-noUi-handle {
  cursor: grab;
  cursor: -webkit-grab;
}
.bk-root .bk-noUi-handle.bk-noUi-active {
  cursor: grabbing;
  cursor: -webkit-grabbing;
}
.bk-root .bk-noUi-tooltip {
  display: none;
  white-space: nowrap;
}
.bk-root .bk-noUi-handle:hover .bk-noUi-tooltip {
  display: block;
}
.bk-root .bk-noUi-horizontal {
  width: 100%;
  height: 10px;
}
.bk-root .bk-noUi-horizontal.bk-noUi-target {
  margin: 5px 0px;
}
.bk-root .bk-noUi-horizontal .bk-noUi-handle {
  width: 14px;
  height: 18px;
  left: -7px;
  top: -5px;
}
.bk-root .bk-noUi-vertical {
  width: 10px;
  height: 100%;
}
.bk-root .bk-noUi-vertical.bk-noUi-target {
  margin: 0px 5px;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle {
  width: 18px;
  height: 14px;
  left: -5px;
  top: -7px;
}
.bk-root .bk-noUi-handle:after,
.bk-root .bk-noUi-handle:before {
  display: none;
}
.bk-root .bk-noUi-connect {
  box-shadow: none;
}
.bk-root .pika-single {
  z-index: 9999;
  display: block;
  position: relative;
  color: #333;
  background: #fff;
  border: 1px solid #ccc;
  border-bottom-color: #bbb;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}
.bk-root .pika-single:before,
.bk-root .pika-single:after {
  content: " ";
  display: table;
}
.bk-root .pika-single:after {
  clear: both;
}
.bk-root .pika-single.is-hidden {
  display: none;
}
.bk-root .pika-single.is-bound {
  position: absolute;
  box-shadow: 0 5px 15px -5px rgba(0, 0, 0, 0.5);
}
.bk-root .pika-lendar {
  float: left;
  width: 240px;
  margin: 8px;
}
.bk-root .pika-title {
  position: relative;
  text-align: center;
}
.bk-root .pika-label {
  display: inline-block;
  position: relative;
  z-index: 9999;
  overflow: hidden;
  margin: 0;
  padding: 5px 3px;
  font-size: 14px;
  line-height: 20px;
  font-weight: bold;
  background-color: #fff;
}
.bk-root .pika-title select {
  cursor: pointer;
  position: absolute;
  z-index: 9998;
  margin: 0;
  left: 0;
  top: 5px;
  opacity: 0;
}
.bk-root .pika-prev,
.bk-root .pika-next {
  display: block;
  cursor: pointer;
  position: relative;
  outline: none;
  border: 0;
  padding: 0;
  width: 20px;
  height: 30px;
  /* hide text using text-indent trick, using width value (it's enough) */
  text-indent: 20px;
  white-space: nowrap;
  overflow: hidden;
  background-color: transparent;
  background-position: center center;
  background-repeat: no-repeat;
  background-size: 75% 75%;
  opacity: 0.5;
}
.bk-root .pika-prev:hover,
.bk-root .pika-next:hover {
  opacity: 1;
}
.bk-root .pika-prev,
.bk-root .is-rtl .pika-next {
  float: left;
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAUklEQVR42u3VMQoAIBADQf8Pgj+OD9hG2CtONJB2ymQkKe0HbwAP0xucDiQWARITIDEBEnMgMQ8S8+AqBIl6kKgHiXqQqAeJepBo/z38J/U0uAHlaBkBl9I4GwAAAABJRU5ErkJggg==');
}
.bk-root .pika-next,
.bk-root .is-rtl .pika-prev {
  float: right;
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAU0lEQVR42u3VOwoAMAgE0dwfAnNjU26bYkBCFGwfiL9VVWoO+BJ4Gf3gtsEKKoFBNTCoCAYVwaAiGNQGMUHMkjGbgjk2mIONuXo0nC8XnCf1JXgArVIZAQh5TKYAAAAASUVORK5CYII=');
}
.bk-root .pika-prev.is-disabled,
.bk-root .pika-next.is-disabled {
  cursor: default;
  opacity: 0.2;
}
.bk-root .pika-select {
  display: inline-block;
}
.bk-root .pika-table {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0;
  border: 0;
}
.bk-root .pika-table th,
.bk-root .pika-table td {
  width: 14.28571429%;
  padding: 0;
}
.bk-root .pika-table th {
  color: #999;
  font-size: 12px;
  line-height: 25px;
  font-weight: bold;
  text-align: center;
}
.bk-root .pika-button {
  cursor: pointer;
  display: block;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  outline: none;
  border: 0;
  margin: 0;
  width: 100%;
  padding: 5px;
  color: #666;
  font-size: 12px;
  line-height: 15px;
  text-align: right;
  background: #f5f5f5;
}
.bk-root .pika-week {
  font-size: 11px;
  color: #999;
}
.bk-root .is-today .pika-button {
  color: #33aaff;
  font-weight: bold;
}
.bk-root .is-selected .pika-button,
.bk-root .has-event .pika-button {
  color: #fff;
  font-weight: bold;
  background: #33aaff;
  box-shadow: inset 0 1px 3px #178fe5;
  border-radius: 3px;
}
.bk-root .has-event .pika-button {
  background: #005da9;
  box-shadow: inset 0 1px 3px #0076c9;
}
.bk-root .is-disabled .pika-button,
.bk-root .is-inrange .pika-button {
  background: #D5E9F7;
}
.bk-root .is-startrange .pika-button {
  color: #fff;
  background: #6CB31D;
  box-shadow: none;
  border-radius: 3px;
}
.bk-root .is-endrange .pika-button {
  color: #fff;
  background: #33aaff;
  box-shadow: none;
  border-radius: 3px;
}
.bk-root .is-disabled .pika-button {
  pointer-events: none;
  cursor: default;
  color: #999;
  opacity: 0.3;
}
.bk-root .is-outside-current-month .pika-button {
  color: #999;
  opacity: 0.3;
}
.bk-root .is-selection-disabled {
  pointer-events: none;
  cursor: default;
}
.bk-root .pika-button:hover,
.bk-root .pika-row.pick-whole-week:hover .pika-button {
  color: #fff;
  background: #ff8000;
  box-shadow: none;
  border-radius: 3px;
}
.bk-root .pika-table abbr {
  border-bottom: none;
  cursor: help;
}
